version

package
v0.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Value string

Value is set by release builds using a linker flag.

Functions

func Current

func Current() string

Current returns the version injected by the build, the module version recorded by the Go toolchain, or "dev" for an unversioned local build.

Types

This section is empty.

Jump to